*Replication Code for Mechanisms of Morality: Sources of Support for Humanitarian Intervention
*Sarah Kreps and Sarah Maxey
*March 2017
*This file replications the results from the manuscript. File 2 replicates the 
*results from the appendix. Note, the mediation analysis uses simulations to 
*estimate the average causal mediation effect and percentage of the total effect 
*mediated through each mechanism. Estimates will vary slightly across iterations. 


version 12.1

*Set command directory to location where replication files are saved

***Experiment One: Preliminary Assessment of Support
*Load Data
use "ExperimentOne.dta", clear

*1. Compare levels of support
prtest supportbi, by(treatmentid)

*2. Table 1
	*Moral Obligation
	prtest moralbi, by(treatmentid)

	*Burden-Sharing
	prtest helpbi, by(treatmentid)

	*High Casualties
	prtest casualtiesbi, by(treatmentid)

	*Financial Costs
	prtest costsbi, by(treatmentid)

	*Terrorism
	prtest instabilitybi, by(treatmentid)
	
	*Spillover
	prtest spilloverbi, by(treatmentid)
	
	*Economic Loss
	prtest economicbi, by(treatmentid)
	
	*Reputation
	prtest resolvebi, by(treatmentid)


********************************************************************************
********************************************************************************
***Experiment Two: Context and Mechanisms
*Load Data
use "ExperimentTwo.dta", clear

*1. Compare levels of support
prtest supportbi if treatmentid==1|treatmentid==6, by(treatmentid)

*2. Table 3
	*Baseline
	prtest supportbi if treatmentid==1|treatmentid==6, by(treatmentid)
	
	*No Multilateral Help
	prtest supportbi if treatmentid==2|treatmentid==7, by(treatmentid)
	
	*Multilateral Help
	prtest supportbi if treatmentid==3|treatmentid==8, by(treatmentid)
	
	*Effect of Multilateral Help
	prtest supportbi if treatmentid==2|treatmentid==3, by(treatmentid)
	prtest supportbi if treatmentid==7|treatmentid==8, by(treatmentid)
	
	*No Reputational Costs
	prtest supportbi if treatmentid==4|treatmentid==9, by(treatmentid)
	
	*Reputational Costs
	prtest supportbi if treatmentid==5|treatmentid==10, by(treatmentid)
	
	*Effect of Reputational Costs
	prtest supportbi if treatmentid==4|treatmentid==5, by(treatmentid)
	prtest supportbi if treatmentid==9|treatmentid==10, by(treatmentid)

*3. Table 4
	*Multilateral Help
	logit supportbi hitreatment help2 hitreatment##help2
	
	*Reputational Costs
	logit supportbi hitreatment resolve2 hitreatment##resolve2

*4. Mediation analysis
medeff(logit moralbi hitreatment) (logit supportbi hitreatment moralbi), /// 
	treat(hitreatment) mediate(moralbi)


********************************************************************************
********************************************************************************
***Experiment 3: Mechanisms of Morality
*Load Data
use "ExperimentThree.dta", clear

*Table 5
*Harm to Civilians
	*Treatment Effect
	prtest harm, by(treatmentid)
	*Mediation Effects
	medeff(logit harm treatmentid) (logit supportbi treatmentid harm), /// 
		treat(treatmentid) mediate(harm)
*Perpetrators able to get away with of human rights abuse
	*Treatment Effect
	prtest hrights, by(treatmentid)
	*Mediation Effects
	medeff(logit hrights treatmentid) (logit supportbi treatmentid hrights), /// 
		treat(treatmentid) mediate(hrights)
*Disorder within international society
	*Treatment Effect
	prtest disorder, by(treatmentid)
	*Mediation Effects
	medeff(logit disorder treatmentid) (logit supportbi treatmentid disorder), /// 
		treat(treatmentid) mediate(disorder)
*Betray values and identity
	*Treatment Effect
	prtest values, by(treatmentid)
	*Mediation Effects
	medeff(logit values treatmentid) (logit supportbi treatmentid values), /// 
		treat(treatmentid) mediate(values)
*Violate expecations of civilized country
	*Treatment Effect
	prtest civilized, by(treatmentid)
	*Mediation Effects
	medeff(logit civilized treatmentid) (logit supportbi treatmentid civilized), /// 
		treat(treatmentid) mediate(civilized)
*Boots on the ground
	*Treatment Effect
	prtest boots2, by(treatmentid)
	*Mediation Effects
	medeff(logit boots2 treatmentid) (logit supportbi treatmentid boots2), /// 
		treat(treatmentid) mediate(boots2)
*Own security
	*Treatment Effect
	prtest security, by(treatmentid)
	*Mediation Effects
	medeff(logit security treatmentid) (logit supportbi treatmentid security), /// 
		treat(treatmentid) mediate(security)
*Allies' security
	*Treatment Effect
	prtest othersecurity, by(treatmentid)
	*Mediation Effects
	medeff(logit othersecurity treatmentid) (logit supportbi treatmentid othersecurity), /// 
		treat(treatmentid) mediate(othersecurity)


********************************************************************************
********************************************************************************
***Partisan Identification and Public Attitudes

*1. Table 6
*Experiment One
	*Load data
	use "ExperimentOne.dta", clear
	*Democrats
	prtest supportbi if democrat==1, by(treatmentid)
	*Republicans
	prtest supportbi if republican==1, by(treatmentid)
	*Independents
	prtest supportbi if independent==1, by(treatmentid)
	*Overall
	prtest supportbi, by(treatmentid)
	
*Experiment Two
	*Load data
	use "ExperimentTwo.dta", clear
	*Democrats
	prtest supportbi if democrat==1, by(hitreatment)
	*Republicans
	prtest supportbi if republican==1, by(hitreatment)
	*Independents
	prtest supportbi if independent==1, by(hitreatment)
	*Overall
	prtest supportbi, by(hitreatment)
	
*Experiment Three
	*Load data
	use "ExperimentThree.dta", clear
	*Democrats
	prtest supportbi if democrat==1, by(treatmentid)
	*Republicans
	prtest supportbi if republican==1, by(treatmentid)
	*Independents
	prtest supportbi if independent==1, by(treatmentid)
	*Overall
	prtest supportbi, by(treatmentid)


*2. Table 7
*Experiment One
	*Load Data
	use "ExperimentOne.dta", clear
	*Democrats
	prtest moralbi if democrat==1, by(treatmentid)
	*Republicans
	prtest moralbi if republican==1, by(treatmentid)
	*Independents
	prtest moralbi if independent==1, by(treatmentid)
	*Overall
	prtest moralbi, by(treatmentid)
	
*Experiment Two
	*Load Data
	use "ExperimentTwo.dta", clear
	*Democrats
	prtest moralbi if democrat==1, by(hitreatment)
	*Republicans
	prtest moralbi if republican==1, by(hitreatment)
	*Independents
	prtest moralbi if independent==1, by(hitreatment)
	*Overall
	prtest moralbi, by(hitreatment)

*Experiment Three
	*Load Data
	use "ExperimentThree.dta", clear
	*Democrats
	prtest harm if democrat==1, by(treatmentid)
	*Republicans
	prtest harm if republican==1, by(treatmentid)
	*Independents
	prtest harm if independent==1, by(treatmentid)
	*Overall
	prtest harm, by(treatmentid)

